@@ -28,11 +28,4 @@
 Defines all interaction modes used in Adhesion
 """
 
-try:
-    from importlib.metadata import version
-
-    __version__ = version(__name__)
-except ImportError:
-    from pkg_resources import get_distribution
-
-    __version__ = get_distribution(__name__).version
+from .DiscoverVersion import __version__  # noqa: F401
